#!/bin/bash

KER_VER="$(uname -r)"
echo "Detected kernel version: $KER_VER"

if lsmod | grep -qw "^88XXau_vtx"; then
    echo "Modified 88XXau_vtx kernel module already loaded"
    exit 0
fi


if ! [ -f /lib/modules/$KER_VER/kernel/drivers/net/wireless/88XXau_vtx.ko ]; then 
    echo "[WARNING] RTL8812AU .ko missing!"
    exit 0
fi

echo "Enabling 88XXau_vtx to run on bootup..."
sed -i '/88XXau/d' /etc/modules
echo "Adding 88XXau_vtx kernel module to /etc/modules..."
echo 88XXau_vtx >> /etc/modules
if [ -f /etc/modprobe.d/blacklist-88XXau_vtx.conf ]; then
    echo "Removing 88XXau_vtx kernel module from blacklist"
    rm /etc/modprobe.d/blacklist-88XXau_vtx.conf
fi

if ! [ -f /etc/modprobe.d/blacklist-88XXau.conf ]; then
    echo "Stopping 88XXau from running on bootup, adding to blacklist"
    echo blacklist 88XXau >> /etc/modprobe.d/blacklist-88XXau.conf
fi

echo "Removing 88XXau kernel module..."
rmmod 88XXau
echo "Loading 88XXau_vtx kernel module..."
insmod /lib/modules/$KER_VER/kernel/drivers/net/wireless/88XXau_vtx.ko
echo "Updating kernel module dependencies..."
/sbin/depmod -a "$KER_VER"