#!/bin/bash

# Print starting message
echo "Starting the process to retrieve SoC serial number and generate VTX key..."

# Check if ADB is available
if ! command -v adb &> /dev/null; then
    echo "Error: adb command not found. Please install ADB and try again."
    exit 1
fi

# Get SoC serial number from device
SOC_ID=$(adb shell cat /sys/devices/soc0/serial_number | tr -d '\r')

# Check if the command was successful
if [ -z "$SOC_ID" ]; then
    echo "Error: Failed to retrieve SoC serial number. Ensure your device is connected and try again."
    exit 1
fi

echo "Retrieved SoC Serial Number: $SOC_ID"

# Check if voxl-vtx-keygen is available
if ! command -v voxl-vtx-keygen &> /dev/null; then
    echo "Error: voxl-vtx-keygen command not found. Please install it and try again."
    exit 1
fi

# Run voxl-vtx-keygen with the retrieved SoC ID
echo "Generating VTX key using SoC Serial Number..."
VTX_KEY=$(voxl-vtx-keygen -b "$SOC_ID")

# Check if the command was successful
if [ -z "$VTX_KEY" ]; then
    echo "Error: Failed to generate VTX key."
    exit 1
fi

HASH=$(md5sum vtx.key)
echo "Successfully generated VTX key: $VTX_KEY"
echo "MD5SUM: $HASH"
